@@ -847,8 +847,8 @@ class Progress(_Progress):
             stats[libvirt.VIR_DOMAIN_JOB_MEMORY_TOTAL],
             stats[libvirt.VIR_DOMAIN_JOB_MEMORY_PROCESSED],
             stats[libvirt.VIR_DOMAIN_JOB_MEMORY_REMAINING],
-            stats[libvirt.VIR_DOMAIN_JOB_MEMORY_BPS],
-            stats[libvirt.VIR_DOMAIN_JOB_MEMORY_CONSTANT],
+            stats.get(libvirt.VIR_DOMAIN_JOB_MEMORY_BPS, 0),
+            stats.get(libvirt.VIR_DOMAIN_JOB_MEMORY_CONSTANT, 0),
             stats.get(libvirt.VIR_DOMAIN_JOB_COMPRESSION_BYTES, 0),
             # available since libvirt 1.3
             stats.get('memory_dirty_rate', -1),
